@@ -12,7 +12,7 @@ if TYPE_CHECKING:
 
 def create_engine(database_url: engine.URL) -> AsyncEngine:
     engine = create_async_engine(
-        database_url, echo=False and settings.log_level == "DEBUG"
+        database_url, echo=False and settings.log_level == "DEBUG", pool_recycle=1800
     )
     dialect_name = engine.dialect.name
 
