@@ -2,7 +2,7 @@ from fief.models.admin_api_key import AdminAPIKey
 from fief.models.admin_session_token import AdminSessionToken
 from fief.models.authorization_code import AuthorizationCode
 from fief.models.base import MainBase, WorkspaceBase
-from fief.models.client import Client
+from fief.models.client import Client, ClientType
 from fief.models.generics import M_UUID, M
 from fief.models.grant import Grant
 from fief.models.login_session import LoginSession
@@ -21,6 +21,7 @@ __all__ = [
     "AdminSessionToken",
     "AuthorizationCode",
     "Client",
+    "ClientType",
     "Grant",
     "LoginSession",
     "MainBase",
